@@ -55,7 +55,6 @@ sub new($)
   $$self{objOutputter} = $objOutputter;
   $$self{filename} = "(none)";
   $$self{line_num} = 0;
-  $$self{mergecdocs} = 0;
 
   $$self{level} = 0;
   $$self{class} = "";
@@ -110,6 +109,7 @@ sub parse_and_build_output($)
     if ($token eq "_IGNORE")     { $self->on_ignore(); next;} #Ignore a function.
     if ($token eq "_IGNORE_SIGNAL")     { $self->on_ignore_signal(); next;} #Ignore a signal.
     if ($token eq "_WRAP_METHOD")     { $self->on_wrap_method(); next;}
+    if ($token eq "_WRAP_METHOD_DOCS_ONLY")     { $self->on_wrap_method_docs_only(); next;}
     if ($token eq "_WRAP_CORBA_METHOD")     { $self->on_wrap_corba_method(); next;} #Used in libbonobo*mm.
     if ($token eq "_WRAP_SIGNAL") { $self->on_wrap_signal(); next;}
     if ($token eq "_WRAP_PROPERTY") { $self->on_wrap_property(); next;}
@@ -462,12 +462,9 @@ sub on_defs($)
   GtkDefs::read_defs("$$self{defsdir}", "$defsfile.defs");
 
   #Read the documentation too, so that we can merge it into the generated C++ code:
-  if($$self{mergecdocs})
-  {
-    my $docs_filename = $defsfile . "_docs.xml";
-    my $docs_filename_override = $defsfile . "_docs_override.xml";
-    DocsParser::read_defs("$$self{defsdir}", $docs_filename, $docs_filename_override);
-  }
+  my $docs_filename = $defsfile . "_docs.xml";
+  my $docs_filename_override = $defsfile . "_docs_override.xml";
+  DocsParser::read_defs("$$self{defsdir}", $docs_filename, $docs_filename_override);
 }
 
 # void on_open_brace()
@@ -745,9 +742,9 @@ sub on_wrap_method($)
   $argCFunctionName = string_trim($argCFunctionName);
 
   #Get the c function's details:
-  
+
   #Checks that it's not empty and that it contains no whitespace.
-  if ($argCFunctionName =~ /^\S+$/ ) 
+  if ($argCFunctionName =~ /^\S+$/ )
   {
     #c-name. e.g. gtk_clist_set_column_title
     $objCfunc = GtkDefs::lookup_function($argCFunctionName);
@@ -772,13 +769,75 @@ sub on_wrap_method($)
       $$objCfunc{throw_any_errors} = 1;
     }
   }
-
+   
   my $commentblock = "";
   $commentblock = DocsParser::lookup_documentation($argCFunctionName);
 
   $objOutputter->output_wrap_meth($filename, $line_num, $objCppfunc, $objCfunc, $argCppMethodDecl, $commentblock);
 }
 
+# void on_wrap_method_docs_only()
+sub on_wrap_method_docs_only($)
+{
+  my ($self) = @_;
+  my $objOutputter = $$self{objOutputter};
+
+  if( !($self->check_for_eof()) )
+  {
+   return;
+  }
+
+  my $filename = $$self{filename};
+  my $line_num = $$self{line_num};
+
+  my $str = $self->extract_bracketed_text();
+  my @args = string_split_commas($str);
+
+  my $entity_type = "method";
+
+  if (!$$self{in_class})
+    {
+      print STDERR "$filename:$line_num:_WRAP macro encountered outside class\n";
+      return;
+    }
+
+  my $objCfunc;
+
+  # handle first argument
+  my $argCFunctionName = $args[0];
+  $argCFunctionName = string_trim($argCFunctionName);
+
+  #Get the c function's details:
+  
+  #Checks that it's not empty and that it contains no whitespace.
+  if ($argCFunctionName =~ /^\S+$/ ) 
+  {
+    #c-name. e.g. gtk_clist_set_column_title
+    $objCfunc = GtkDefs::lookup_function($argCFunctionName);
+
+    if(!$objCfunc) #If the lookup failed:
+    {
+      $objOutputter->output_wrap_failed($argCFunctionName, "method defs lookup failed (1)");
+      return;
+    }
+  }
+
+  # Extra ref needed?
+  while(scalar(@args) > 1) # If the optional ref/err arguments are there.
+  {
+    my $argRef = string_trim(pop @args);
+    if($argRef eq "errthrow")
+    {
+      $$objCfunc{throw_any_errors} = 1;
+    }
+  }
+
+  my $commentblock = "";
+  $commentblock = DocsParser::lookup_documentation($argCFunctionName);
+
+  $objOutputter->output_wrap_meth_docs_only($filename, $line_num, $commentblock);
+}
+
 sub on_wrap_ctor($)
 {
   my ($self) = @_;
@@ -873,6 +932,7 @@ sub on_wrap_signal($)
   $argCName = string_unquote($argCName);
 
   my $bCustomDefaultHandler = 0;
+  my $bNoDefaultHandler = 0;
   if(scalar(@args) > 2) # If the optional argument is there.
   {
     my $argRef = string_trim($args[2]);
@@ -880,12 +940,15 @@ sub on_wrap_signal($)
     {
       $bCustomDefaultHandler = 1;
     }
+
+    if($argRef eq "no_default_handler")
+    {
+      $bNoDefaultHandler = 1;
+    }
   }
 
-  my $bImplement = 1;
-  if( $bCustomDefaultHandler eq 1) { $bImplement = 0 };
 
-  $self->output_wrap_signal( $argCppDecl, $argCName, $$self{filename}, $$self{line_num}, $bImplement);
+  $self->output_wrap_signal( $argCppDecl, $argCName, $$self{filename}, $$self{line_num}, $bCustomDefaultHandler, $bNoDefaultHandler);
 }
 
 # void on_wrap_vfunc()
@@ -1041,11 +1104,11 @@ sub output_wrap_check($$$$$$)
 
 }
 
-# void output_wrap($CppDecl, $signal_name, $filename, $line_num)
+# void output_wrap($CppDecl, $signal_name, $filename, $line_num, $bCustomDefaultHandler, $bNoDefaultHandler)
 # Also used for vfunc.
 sub output_wrap_signal($$$$$$)
 {
-  my ($self, $CppDecl, $signal_name, $filename, $line_num, $bImplement) = @_;
+  my ($self, $CppDecl, $signal_name, $filename, $line_num, $bCustomDefaultHandler, $bNoDefaultHandler) = @_;
 
   #Some checks:
   $self->output_wrap_check($CppDecl, $signal_name, $filename, $line_num, "WRAP_SIGNAL");
@@ -1088,8 +1151,15 @@ sub output_wrap_signal($$$$$$)
 #  }
 
   $objOutputter->output_wrap_sig_decl($filename, $line_num, $objCSignal, $objCppSignal, $signal_name);
-  $objOutputter->output_wrap_default_signal_handler_h($filename, $line_num, $objCppSignal, $objCSignal);
-  $objOutputter->output_wrap_default_signal_handler_cc($filename, $line_num, $objCppSignal, $objCSignal, $bImplement);
+
+  if($bNoDefaultHandler eq 0)
+  {
+    $objOutputter->output_wrap_default_signal_handler_h($filename, $line_num, $objCppSignal, $objCSignal);
+
+    my $bImplement = 1;
+    if($bCustomDefaultHandler) { $bImplement = 0; }
+    $objOutputter->output_wrap_default_signal_handler_cc($filename, $line_num, $objCppSignal, $objCSignal, $bImplement);
+  }
 }
 
 # void output_wrap($CppDecl, $signal_name, $filename, $line_num)
